#![no_std]

use arduino_hal::{hal::port::*, pac::*};
use static_pins_macros::impl_static_pin;

#[macro_export]
macro_rules! impl_static_pins {
    ($($pin:expr), +) => {
        pub trait StaticPinOps {
            type Port;
            const PIN_NUM: u8;
            const PIN_POS: u8;

            fn into_input();
            fn into_output();
            fn into_output_high();
            fn into_pull_up_input();

            fn write(data: u8);
            fn read() -> u8;

            fn is_low() -> bool;
            fn is_high() -> bool;

            fn set_low();
            fn set_high();
        }

        $(
            impl_static_pin!($pin);
        )+
    }
}

#[cfg(feature = "sparkfun-promicro")]
impl_static_pins!(
    PB0, PB1, PB2, PB3, PB4, PB5, PB6, PB7, PC6, PC7, PD0, PD1, PD2, PD3, PD4, PD5, PD6, PD7, PE2,
    PE6, PF0, PF1, PF4, PF5, PF6, PF7
);
